package Processor;

import org.apache.camel.Exchange;
import org.apache.camel.ExchangePattern;
import org.apache.camel.Message;
import org.apache.camel.Processor;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.http.common.HttpMessage;
import org.apache.camel.impl.DefaultCamelContext;
import org.apache.camel.model.ModelCamelContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;


/**
 * Created by ztest on 2020/6/9
 */
public class HttpProcessor implements Processor {
    private static final Logger logger = LoggerFactory.getLogger(HttpProcessor.class);

    public void process(Exchange exchange) throws Exception {
        logger.info("showId" + exchange.getExchangeId());
        HttpMessage message = (HttpMessage) exchange.getIn();
        InputStream bodyStream = (InputStream) message.getBody();
        String inputContext = this.analysisMessage(bodyStream);
        bodyStream.close();
        // 存入到exchange的out区域
        if (exchange.getPattern() == ExchangePattern.InOut) {
            Message outMessage = exchange.getOut();
            outMessage.setHeader("route","cheese");
            outMessage.setBody("{\n" +
                    "\t\"baseInfo\": {\n" +
                    "\t\t\"x2\": \"xx\",\n" +
                    "\t\t\"x2\": \"118\",\n" +
                    "        \"x3\": \"{{rno}}\"\n" +
                    "\t},\"params\":{\n" +
                    "        \"xx1\":\"xxx\",\n" +
                    "        \"xx2\":\"ocZ-xxx\"\n" +
                    "    }\n" +
                    "}\n");
        }
    }

    /**
     * 从stream中分析字符串内容
     *
     * @param bodyStream
     * @return
     */
    private String analysisMessage(InputStream bodyStream) throws IOException {
        ByteArrayOutputStream outStream = new ByteArrayOutputStream();
        byte[] contextBytes = new byte[4096];
        int realLen;
        while ((realLen = bodyStream.read(contextBytes, 0, 4096)) != -1) {
            outStream.write(contextBytes, 0, realLen);
        }

        // 返回从Stream中读取的字串
        try {
            return new String(outStream.toByteArray(), "UTF-8");
        } finally {
            outStream.close();
        }
    }
}
